@@ -48,6 +48,7 @@
  */
 package com.openexchange.usm.api.exceptions;
 
+import org.apache.commons.httpclient.Header;
 import org.json.JSONObject;
 
 /**
@@ -59,7 +60,8 @@ import org.json.JSONObject;
  * </ul>
  * The http status code can be retrieved using getHttpStatusCode(), it will
  * return -1 if no status code is available. The originating exception (if
- * present) can be retrieved using the getCause() method.<br>
+ * present) can be retrieved using the getCause() method.
+ * Additional headers may be set to add it to the EAS http response.<br>
  * Since this can happen on every synchronization call, it is implemented as a
  * RuntimeException to avoid adding it to each method signature.
  * 
@@ -78,19 +80,31 @@ public class OXCommunicationException extends USMException {
 	private final JSONObject _jsonError;
 
 	private final String _serverResponse;
+	
+	private final Header[] _headers;
 
 	public OXCommunicationException(int errorCode, int statusCode) {
 		super(errorCode, "http status code " + statusCode + " received");
 		_httpStatusCode = statusCode;
 		_jsonError = null;
 		_serverResponse = null;
+		_headers = null;
 	}
 
+    public OXCommunicationException(int errorCode, int statusCode, Header[] headers) {
+        super(errorCode, "http status code " + statusCode + " received");
+        _httpStatusCode = statusCode;
+        _jsonError = null;
+        _serverResponse = null;
+        _headers = headers;
+    }
+
 	public OXCommunicationException(int errorCode, Throwable cause) {
 		super(errorCode, "Exception occurred during communication with OX server", cause);
 		_httpStatusCode = -1;
 		_jsonError = null;
 		_serverResponse = null;
+        _headers = null;
 	}
 
 	public OXCommunicationException(int errorCode, JSONObject errorDetails) {
@@ -98,6 +112,7 @@ public class OXCommunicationException extends USMException {
 		_httpStatusCode = -1;
 		_jsonError = errorDetails;
 		_serverResponse = null;
+        _headers = null;
 	}
 
 	public OXCommunicationException(int errorCode, String message, JSONObject errorDetails) {
@@ -105,6 +120,7 @@ public class OXCommunicationException extends USMException {
 		_httpStatusCode = -1;
 		_jsonError = errorDetails;
 		_serverResponse = null;
+        _headers = null;
 	}
 
 	public OXCommunicationException(int errorCode, String message, Throwable cause) {
@@ -112,6 +128,7 @@ public class OXCommunicationException extends USMException {
 		_httpStatusCode = -1;
 		_jsonError = null;
 		_serverResponse = null;
+        _headers = null;
 	}
 	
 	public OXCommunicationException(int errorCode, String message, Throwable cause, String serverResponse) {
@@ -119,6 +136,7 @@ public class OXCommunicationException extends USMException {
 		_httpStatusCode = -1;
 		_jsonError = null;
 		_serverResponse = serverResponse;
+        _headers = null;
 	}
 
 	public OXCommunicationException(int errorCode, String message, String serverResponse) {
@@ -126,6 +144,7 @@ public class OXCommunicationException extends USMException {
 		_httpStatusCode = -1;
 		_jsonError = null;
 		_serverResponse = serverResponse;
+        _headers = null;
 	}
 
 	public OXCommunicationException(int errorCode, String serverResponse) {
@@ -133,6 +152,7 @@ public class OXCommunicationException extends USMException {
 		_httpStatusCode = -1;
 		_jsonError = null;
 		_serverResponse = serverResponse;
+        _headers = null;
 	}
 
 	public boolean isHttpStatusCodeSet() {
@@ -178,6 +198,10 @@ public class OXCommunicationException extends USMException {
 			super.addStacktrace(t, errorDetailsObject);
 	}
 
+    public Header[] getHeaders() {
+        return _headers;
+    }
+
 	@Override
 	public String toString() {
 		StringBuilder sb = new StringBuilder(super.toString());
@@ -187,6 +211,12 @@ public class OXCommunicationException extends USMException {
 			sb.append(", json-error=").append(_jsonError);
 		if (_serverResponse != null)
 			sb.append(", server-response=").append(_serverResponse);
+        if (_headers != null) {
+            sb.append(", server-specific-headers=");
+                for (Header header: _headers) {
+                    sb.append(header.getName() + ":" + header.getValue() + ",");
+            }
+        }
 		return sb.toString();
 	}
 }
