@@ -124,7 +124,8 @@ public class NestedMail implements Serializable {
     }
 
     private boolean isSpecialField(String fieldName) {
-        return ID.equals(fieldName) || FOLDER_ID.equals(fieldName) || ATTACHMENT.equals(fieldName);
+        /* removed test on ID, because it is needed due to bug 56285 */ 
+        return FOLDER_ID.equals(fieldName) || ATTACHMENT.equals(fieldName);
     }
 
     public Map<String, Object> getMap() {
@@ -164,4 +165,20 @@ public class NestedMail implements Serializable {
         }
         return o;
     }
+    
+    public String getFilename() {
+        Object v = _map.get(FILENAME);
+        if (v != null) {
+            return (String) v;
+        }
+        return "";
+    }
+
+    public String getId() {
+        Object v = _map.get(ID);
+        if (v != null) {
+            return (String) v;
+        }
+        return "";
+    }
 }
