@@ -25,7 +25,7 @@ public class Vacation {
     private static final String ACTIVE = "active";
     public static final String RULE_ID = "vacation";
     private static final String RULENAME = "rulename";
-    private static final String RULENAME_DEFAULT = "Abwesenheit";
+    public static final String RULENAME_DEFAULT = "vacation notice";
     private static final String ACTIONCMDS = "actioncmds";
     private static final String TEST = "test";
     private static final String TESTS = "tests";
@@ -85,7 +85,12 @@ public class Vacation {
 		JSONArray actionCmds = rule.optJSONArray(ACTIONCMDS);
 		if (actionCmds != null && actionCmds.length() > 0) {
 			JSONObject actionCmd = actionCmds.optJSONObject(0);
-			days = actionCmd.optInt(DAYS, DAYS_DEFAULT);
+			if (actionCmd.has(DAYS)) {
+			    days = actionCmd.optInt(DAYS, DAYS_DEFAULT);
+			}
+			else {
+			    days = -1;
+			}
 			text = actionCmd.optString(TEXT);
 			subject = actionCmd.optString(SUBJECT);
 			JSONArray addressesJSON = actionCmd.has(ADDRESSES) ? actionCmd
@@ -110,7 +115,7 @@ public class Vacation {
 	}
 
 	public boolean hasTimes() {
-	    return getStartTime() != 0 && getEndTime() != 0;
+	    return getStartTime() != 0 || getEndTime() != 0;
 	}
 	
     public void removeTimes() {
@@ -121,18 +126,26 @@ public class Vacation {
     public JSONObject toJSONObject() throws JSONException {
         JSONObject actionCmd = new JSONObject();
         actionCmd.put(ID, RULE_ID);
-        actionCmd.put(DAYS, days);
+        if (days > -1) {
+            actionCmd.put(DAYS, days);
+        }
         if (!addresses.isEmpty())
             actionCmd.put(ADDRESSES, new JSONArray(addresses));
         actionCmd.put(TEXT, text);
-        actionCmd.put(SUBJECT, subject);
+        if (!subject.isEmpty()) {
+            actionCmd.put(SUBJECT, subject);
+        }
         
         JSONObject test = new JSONObject();
         if (hasTimes()){
             test.put(ID, "allof");
             JSONArray tests = new JSONArray();
-            tests.put(createDateTest(COMPARISON_GE, startTime));
-            tests.put(createDateTest(COMPARISON_LE, endTime));
+            if (startTime > 0) {
+                tests.put(createDateTest(COMPARISON_GE, startTime));
+            }
+            if (endTime > 0) {
+                tests.put(createDateTest(COMPARISON_LE, endTime));
+            }
             test.put(TESTS, tests); 
         } else {
             test.put(ID, "true");
