@@ -54,7 +54,6 @@ import java.sql.PreparedStatement;
 import java.sql.SQLException;
 import com.openexchange.exception.OXException;
 import com.openexchange.groupware.update.PerformParameters;
-import com.openexchange.groupware.update.Schema;
 import com.openexchange.usm.database.ox.TableDefinition;
 import com.openexchange.usm.database.ox.USMUpdateExceptionCodes;
 import com.openexchange.usm.database.ox.USMUpdateTaskProvider;
@@ -68,18 +67,14 @@ public class USMClearTablesUpdateTaskV2 extends USMBaseUpdateTaskV2 {
 
 	@Override
 	protected void doPerform(PerformParameters params) throws OXException {
-	    Schema schema = params.getSchema();
-	    int contextId = params.getContextId();
-        Connection con = null;
+        Connection con = params.getConnection();
         PreparedStatement stmt = null;
         try {
-            con = _provider.getDatabaseService().getForUpdateTask(contextId);
             DatabaseMetaData metaData = con.getMetaData();
             for (int i = TableDefinition.TABLE_NAMES.length - 1; i >= 0; i--) {
                 String tableName = TableDefinition.TABLE_NAMES[i];
                 if (tableExists(tableName, metaData)) {
-                    stmt = con.prepareStatement("DELETE FROM " + tableName + " WHERE cid = ?");
-                    stmt.setInt(1, contextId);
+                    stmt = con.prepareStatement("DELETE FROM " + tableName);
                     stmt.executeUpdate();
                     stmt.close();
                     stmt = null;
@@ -88,10 +83,7 @@ public class USMClearTablesUpdateTaskV2 extends USMBaseUpdateTaskV2 {
         } catch (SQLException e) {
             throw USMUpdateExceptionCodes.SQL_ERROR.create(e);
         } finally {
-            if (con != null) {
-                Toolkit.close(stmt);
-                _provider.getDatabaseService().backWritable(contextId, con);
-            }
+            Toolkit.close(stmt);
         }
 	}
 
