@@ -53,14 +53,20 @@ import com.openexchange.usm.api.session.DataObject;
 
 public class ContactSorter extends DataObjectSorter {
 
-	private final int _displayNameIndex;
+    private final int _displayNameIndex;
+    private final int _distributionListIndex;
 
 	public ContactSorter(ContentType contentType) {
 		_displayNameIndex = getFieldIndex(contentType, "display_name");
+        _distributionListIndex = getFieldIndex(contentType, "mark_as_distributionlist");
 	}
 
 	@Override
     public int compare(DataObject o1, DataObject o2) {
-		return compareString(o1, o2, _displayNameIndex);
+	    int compareDistributionList = compareBoolean(o1, o2, _distributionListIndex);
+	    if (compareDistributionList == 0)
+	        return compareString(o1, o2, _displayNameIndex);
+	    // sort contacts before distribution lists
+        return compareDistributionList;
 	}
 }
