@@ -369,7 +369,9 @@ public class OXJSONAccessImpl implements OXJSONAccess {
         OXConnectionData data = obtainConnectionData(session);
         String url = getBaseURL() + path;
         if (LOG.isDebugEnabled()) {
-            LOG.debug(session + " GET " + url);
+            LOG.debug(session + " GET " + url + " action " +  action);
+            if (parameters != null && !parameters.isEmpty())
+            	LOG.debug(session + "parameters " + parameters.toString());
         }
         GetMethod method = new GetMethod(url);
         method.setQueryString(generateQueryParameters(action, data.getSessionID(), parameters));
@@ -573,6 +575,20 @@ public class OXJSONAccessImpl implements OXJSONAccess {
         try {
             int statusCode = executeMethod(client, method);
             if (statusCode != HttpStatus.SC_OK) {
+                if (LOG.isDebugEnabled()) {
+                    StringBuffer responseHeaders = new StringBuffer();
+                    for (Header header: method.getResponseHeaders()) {
+                        responseHeaders.append("  " + header.getName() + ":" + header.getValue() + "\n");
+                    }
+                    LOG.debug("OX communication failed, response headers:\n" + responseHeaders.toString());
+                }
+                if (statusCode == 429) {
+                    Header header = method.getResponseHeader("Retry-After");
+                    if (header != null) {
+                        Header[] headers = { header };
+                        throw new OXCommunicationException(OXJSONErrorCode.ACCESSIMPL_HTTP_CONNECTION_ERROR_11, statusCode, headers);
+                    }
+                }
                 throw new OXCommunicationException(OXJSONErrorCode.ACCESSIMPL_HTTP_CONNECTION_ERROR_11, statusCode);
             }
             JSONResult result = OXJSONSupport.parseResult(extractResponseBodyAsBufferedReader(method), null);
@@ -660,6 +676,14 @@ public class OXJSONAccessImpl implements OXJSONAccess {
             if (statusCode != HttpStatus.SC_OK) {
                 throw new OXCommunicationException(OXJSONErrorCode.ACCESSIMPL_INVALID_STATUSCODE_NUMBER_15, statusCode);
             }
+            if (LOG.isTraceEnabled()) {
+                StringBuffer headersList = new StringBuffer();
+                headersList.append("Response-Headers:\n");
+                for (Header header : method.getResponseHeaders()) {
+                    headersList.append("  " + header.getName() + ":" + header.getValue() + "\n");
+                }
+                LOG.debug(headersList.toString());
+            }
             Header responseHeader = method.getResponseHeader("Content-Type");
             if (responseHeader == null) {
                 throw new OXCommunicationException(
@@ -911,10 +935,13 @@ public class OXJSONAccessImpl implements OXJSONAccess {
     private int executeMethod(HttpClient client, HttpMethod method) throws HttpException, IOException {
         if (LOG.isDebugEnabled()) {
             LOG.debug(method.getName() + method.getPath() + "&" + method.getQueryString());
+            StringBuffer requestHeaders = new StringBuffer();
+            for (Header header: method.getRequestHeaders()) {
+                requestHeaders.append("  " + header.getName() + ":" + header.getValue() + "\n");
+            }
+            LOG.debug("Headers:\n" + requestHeaders.toString());
         }
-        for (Header header : method.getRequestHeaders()) {
-            LOG.debug("Header: " + header.getName() + ":" + header.getValue());
-        }
+        
         int status = HttpStatus.SC_NOT_FOUND;
         method.setFollowRedirects(false);
         String redirectFromServer = null;
