@@ -467,6 +467,12 @@ public class SessionManagerImpl implements SessionManager {
         }
     }
 
+    @Override
+    public void removeSession(Session session) {
+        if (session != null && session instanceof SessionImpl)
+            _sessionStorage.removeSession((SessionImpl) session);
+    }
+    
     /**
      * Applies the {@link LogProperties.Name.SESSION_CONTEXT_ID}, {@link LogProperties.Name.SESSION_USER_ID}
      * and the {@link LogProperties.Name.SESSION_SESSION_ID} (masqueraded as an USM session id) values
