@@ -428,7 +428,7 @@ public class IncrementalContentSyncer extends BaseContentSyncer {
 				serverChange = serverModifications.get(f.getID());
 				if (serverChange == null || isClientChangeWithServerCompatible(f, serverChange)) {
 				    if (_journal.isTraceEnabled())
-		                _journal.trace("newServerModification: " + f.toString());
+		                _journal.trace("serverModificationByTheClient: " + f.toString());
 					newServerModifications.add(f);
 					return;
 				}
@@ -446,14 +446,31 @@ public class IncrementalContentSyncer extends BaseContentSyncer {
         Integer lastModifiedIndex = FieldMapStorageImpl.getInstance().getFieldNameToIndexMap(f.getContentType()).get("last_modified");
         if (lastModifiedIndex == null)
             lastModifiedIndex = -1;
+        Integer noteIndex = FieldMapStorageImpl.getInstance().getFieldNameToIndexMap(f.getContentType()).get("note");
+        if (noteIndex == null)
+            noteIndex = -1;
 
         for (int i = 0; i < fields.length; i++) {
             if (i == lastModifiedIndex)
                 continue;
             DataType<?> type = fields[i].getFieldType();
             if (serverChange.isFieldModified(i)) {
-                if (!type.isEqual(f.getFieldContent(i), serverChange.getFieldContent(i)))
+                if (!type.isEqual(f.getFieldContent(i), serverChange.getFieldContent(i))) {
+                    if  (i == noteIndex) {
+                        // we manipulate in AbstractSyncDelegate.simulateServerChangesForAppointments() the note with irrelevant changes 
+                        String clientNote = f.getFieldContent(i) == null ? "" : f.getFieldContent(i).toString().trim();
+                        String serverNote = serverChange.getFieldContent(i) == null ? "" : serverChange.getFieldContent(i).toString().trim();
+                        if (clientNote.equals(serverNote)) {
+                            continue;
+                        }
+                    }
+                    if (_journal.isTraceEnabled()) {
+                        String clientField = f.getFieldContent(i) == null ? "null" : f.getFieldContent(i).toString();
+                        String serverField = serverChange.getFieldContent(i) == null ? "null" : serverChange.getFieldContent(i).toString();
+                        _journal.trace("client-server-conflict of field " + fields[i].toString() + ": " + clientField + " != " + serverField);
+                    }
                     return false;
+                }
             }
         }
 
@@ -463,6 +480,9 @@ public class IncrementalContentSyncer extends BaseContentSyncer {
 	private void handleConflictingModifications(ConflictResolution conflictResolution,
 			DataObjectSet serverModifications, List<ConflictingChange> conflicts,
 			List<DataObject> newServerModifications, DataObject f, DataObject serverChange) throws InternalUSMException {
+        if (_journal.isTraceEnabled()) {
+            _journal.trace("client-server-conflict for: " + f.toString());
+        }
 		switch (conflictResolution) {
 			case ERROR:
 			case ERROR_DELETE_OVER_CHANGE:
