@@ -68,14 +68,18 @@ public class USMSessionCleanupTask implements Runnable {
     private static final Logger log = LoggerFactory.getLogger(USMSessionCleanupTask.class);
 
     /**
-     * Initial delay after startup of SessionManager/TimerService after which the cleanup task is first performed
+     * Initial delay (in seconds) after startup of SessionManager/TimerService after which the cleanup task is first performed
+     * 
+     * Default: 180000 milliseconds (3 minutes)
      */
-    public static final long INITIAL_DELAY = 1000L * 10L * 1L; // 3 minutes
+    public static final long INITIAL_DELAY = 1000L * 60L * 3L; // 3 minutes
 
     /**
-     * Interval between executions of the cleanup task
+     * Interval (in milliseconds) between executions of the cleanup task
+     * 
+     * Default: 86400000 milliseconds (1 day)
      */
-    public static final long EXECUTION_INTERVAL = 1000L * 60L * 1L; // 1 day
+    public static final long EXECUTION_INTERVAL = 24L * 60L * 60L * 1000L; // 1 day
 
     private final SessionManagerImpl _sessionManager;
 
